@@ -34,8 +34,6 @@ class SSHClient(object):
         self.__username = username
         self.__password = password
         self.__connect_timeout = connect_timeout
-        self.__ssh = paramiko.SSHClient()
-        self.__ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         self.__is_active = False
         self.__sftp = None
 
@@ -94,9 +92,9 @@ class SSHClient(object):
 
     def exec(self, cmd, promt_response=[], timeout=60):
         try:
-            os.environ["SSH_COMMAND_TIMEOUT"] = str(timeout)
-            if not self.is_active():
-                raise RuntimeError("ssh transport is not active.")
+            if not self.__is_active:
+                if not self.reconnect():
+                    raise RuntimeError("ssh transport is not active and failed to reconnect.")
             return self._exec(cmd,promt_response,timeout)
         except FunctionTimedOut as e1:
             log.error(f"when run cmd: {cmd}, meets exception.", exc_info=True)
@@ -122,7 +120,7 @@ class SSHClient(object):
 
     def scp_to_remote(self, local_path, remote_path,timeout=120):
         try:
-            if not self.is_active():
+            if not self.__is_active:
                 raise RuntimeError("ssh transport is not active.")
             os.environ["SSH_SCP_TO_REMOTE_TIMEOUT"] = str(timeout)
             return self._scp_to_remote(local_path, remote_path)
@@ -159,7 +157,7 @@ class SSHClient(object):
 
     def scp_file_to_local(self, remote_path, local_path,timeout=120):
         try:
-            if not self.is_active():
+            if not self.__is_active:
                 raise RuntimeError("ssh transport is not active.")
             os.environ["SSH_SCP_FILE_TO_LOCAL_TIMEOUT"] = str(timeout)
             return self._scp_file_to_local(remote_path, local_path)
@@ -177,35 +175,47 @@ class SSHClient(object):
             log.error(f"when scp from remote {remote_path} to local {local_path}, meets exception.", exc_info=True)
             return False
 
-    def is_active(self):
-        for i in range(2):
-            try:
-                if not self.__is_active:
-                    log.info(f" {self.__ip}:{self.__port} | begin to create ssh connect.")
-                    self.__ssh.connect(
-                        self.__ip,
-                        port=self.__port,
-                        username=self.__username,
-                        password=self.__password,
-                        look_for_keys=False,
-                        allow_agent=False,
-                        timeout=self.__connect_timeout
-                    )
+    def reconnect(self):
+        try:
+            self.__sftp.close()
+        except:
+            pass
+        try:
+            self.__ssh.close()
+        except:
+            pass
+        return self.connect()
 
-                stdin, stdout, stderr = self.__ssh.exec_command("ls /")
-                std_output = stdout.read().decode()
-                if "root" in std_output:
-                    log.info(f"{self.__ip}:{self.__port} | successful to ssh:OK.")
-                    self.__sftp = self.__ssh.open_sftp()
-                    self.__is_active = True
-                    return True
-                else:
-                    log.warning(f"{self.__ip}:{self.__port} | failed to ssh. stderr is {stderr.read().decode()}.")
-                    self.__is_active = False
-            except SSHException:
-                log.warning(f" {self.__ip}:{self.__port} | fail create ssh connect.")
+
+    def connect(self):
+        log.info(f" {self.__ip}:{self.__port} | begin to create ssh connect.")
+        try:
+            self.__ssh = paramiko.SSHClient()
+            self.__ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+            self.__ssh.connect(
+                self.__ip,
+                port=self.__port,
+                username=self.__username,
+                password=self.__password,
+                look_for_keys=False,
+                allow_agent=False,
+                timeout=self.__connect_timeout
+            )
+            stdin, stdout, stderr = self.__ssh.exec_command("ls /|grep root")
+            std_output = stdout.read().decode()
+            if "root" in std_output:
+                log.info(f"{self.__ip}:{self.__port} | successful to ssh:OK.")
+                self.__sftp = self.__ssh.open_sftp()
+                self.__is_active = True
+                return True
+            else:
+                log.warning(f"{self.__ip}:{self.__port} | failed to ssh. stderr is {stderr.read().decode()}.")
                 self.__is_active = False
-            except Exception:
-                log.warning(f" {self.__ip}:{self.__port} | fail create ssh connect.")
-                self.__is_active = False
-        return False
+        except Exception as e:
+            log.error(f"{self.__ip}:{self.__port} | failed to ssh connect.", exc_info=True)
+            self.__is_active = False
+            return False
+
+    @property
+    def is_active(self):
+        return self.__is_active
